@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Ported Perl from the book's C code
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0401';
 
 use Moo;
 use strictures 2;
@@ -211,7 +211,7 @@ sub _composem {
 }
 
 
-sub debruijn_n {
+sub de_bruijn {
     my ($self, $n) = @_;
     my $sequence = $n ? debruijn([1,0], $n) : 0;
     return [ split //, $sequence ];
@@ -529,7 +529,7 @@ Music::CreatingRhythms - Ported Perl from the book's C code
 
 =head1 VERSION
 
-version 0.0400
+version 0.0401
 
 =head1 SYNOPSIS
 
@@ -658,15 +658,15 @@ Example:
 
   $got = $mcr->compm(4, 2); # [[1,3],[2,2],[3,1]]
 
-=head2 debruijn_n
+=head2 de_bruijn
 
-  $sequence = $mcr->debruijn_n($n);
+  $sequence = $mcr->de_bruijn($n);
 
 Generate the largest de Bruijn sequence of order B<n>.
 
 Example:
 
-  $got = $mcr->debruijn_n(3); # 1 1 1 0 1 0 0 0
+  $got = $mcr->de_bruijn(3); # 1 1 1 0 1 0 0 0
 
 =head2 euclid
 
